@@ -274,7 +274,7 @@ def _print_instances(instances):
             setattr(instance, 'datastore', instance.datastore['type'])
     utils.print_list(instances, ['id', 'name', 'datastore',
                                  'datastore_version', 'status',
-                                 'flavor_id', 'size'])
+                                 'flavor_id', 'size', 'region'])
 
 
 @utils.arg('--limit', metavar='<limit>', type=int, default=None,
@@ -414,6 +414,18 @@ def do_cluster_reset_status(cs, args):
     cs.clusters.reset_status(cluster)
 
 
+@utils.arg('cluster', metavar='<cluster>',
+           help=_('ID or name of the cluster.'))
+@utils.arg('datastore_version',
+           metavar='<datastore_version>',
+           help=_('A datastore version name or ID.'))
+@utils.service_type('database')
+def do_cluster_upgrade(cs, args):
+    """Upgrades a cluster to a new datastore version."""
+    cluster = _find_cluster(cs, args.cluster)
+    cs.clusters.upgrade(cluster, args.datastore_version)
+
+
 @utils.arg('instance',
            metavar='<instance>',
            type=str,
@@ -526,6 +538,11 @@ def do_update(cs, args):
            choices=LOCALITY_DOMAIN,
            help=_('Locality policy to use when creating replicas. Choose '
                   'one of %(choices)s.'))
+@utils.arg('--region', metavar='<region>',
+           type=str,
+           default=None,
+           help=argparse.SUPPRESS)
+#           help=_('Name of region in which to create the instance.'))
 @utils.service_type('database')
 def do_create(cs, args):
     """Creates a new instance."""
@@ -579,7 +596,9 @@ def do_create(cs, args):
                                    configuration=args.configuration,
                                    replica_of=replica_of,
                                    replica_count=replica_count,
-                                   modules=modules, locality=locality)
+                                   modules=modules,
+                                   locality=locality,
+                                   region_name=args.region)
     _print_instance(instance)
 
 
@@ -647,6 +666,10 @@ def _get_availability_zone(opts_str):
     return _strip_option(opts_str, 'availability_zone', is_required=False)
 
 
+def _get_region(cs, opts_str):
+    return _strip_option(opts_str, 'region', is_required=False)
+
+
 def _get_modules(cs, opts_str):
     modules, opts_str = _strip_option(
         opts_str, 'module', is_required=False, allow_multiple=True)
@@ -756,6 +779,10 @@ def _parse_instance_options(cs, instance_options, for_grow=False):
             if name:
                 instance_info["name"] = name
 
+        region, instance_opts = _get_region(cs, instance_opts)
+        if region:
+            instance_info["region"] = region
+
         if instance_opts:
             raise exceptions.ValidationError(
                 _("Unknown option(s) '%s' specified for instance")
@@ -981,9 +1008,9 @@ def do_backup_create(cs, args):
 @utils.arg('backup', metavar='<backup>',
            help=_('Backup ID of the source backup.'),
            default=None)
-@utils.arg('--region', metavar='<region>', help=_('Region where the source '
-                                                  'backup resides.'),
-           default=None)
+@utils.arg('--region', metavar='<region>', default=None,
+           # help=_('Region where the source backup resides.'))
+           help=argparse.SUPPRESS)
 @utils.arg('--description', metavar='<description>',
            default=None,
            help=_('An optional description for the backup.'))
@@ -1579,18 +1606,32 @@ def do_configuration_patch(cs, args):
 
 @utils.arg('configuration_group', metavar='<configuration_group>',
            help=_('ID or name of the configuration group.'))
+@utils.arg('--limit', metavar='<limit>', type=int, default=None,
+           help=_('Limit the number of results displayed.'))
+@utils.arg('--marker', metavar='<ID>', type=str, default=None,
+           help=_('Begin displaying the results for IDs greater than the '
+                  'specified marker. When used with --limit, set this to '
+                  'the last ID displayed in the previous run.'))
 @utils.service_type('database')
 def do_configuration_instances(cs, args):
     """Lists all instances associated with a configuration group."""
     configuration = _find_configuration(cs, args.configuration_group)
-    params = cs.configurations.instances(configuration)
+    params = cs.configurations.instances(configuration,
+                                         limit=args.limit,
+                                         marker=args.marker)
     utils.print_list(params, ['id', 'name'])
 
 
+@utils.arg('--limit', metavar='<limit>', type=int, default=None,
+           help=_('Limit the number of results displayed.'))
+@utils.arg('--marker', metavar='<ID>', type=str, default=None,
+           help=_('Begin displaying the results for IDs greater than the '
+                  'specified marker. When used with --limit, set this to '
+                  'the last ID displayed in the previous run.'))
 @utils.service_type('database')
 def do_configuration_list(cs, args):
     """Lists all configuration groups."""
-    config_grps = cs.configurations.list()
+    config_grps = cs.configurations.list(limit=args.limit, marker=args.marker)
     utils.print_list(config_grps, [
         'id', 'name', 'description',
         'datastore_name', 'datastore_version_name'])
